==> kolourpaint-16.12.0.tar.xz: kolourpaint-16.12.0/layers/selections/text/kpPreeditText.h <==

/*
   Copyright (c) 2010 Tasuku Suzuki <stasuku@gmail.com>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpPreeditText_H
#define kpPreeditText_H

#include <QColor>
#include <QInputMethodEvent>
#include <QPoint>

class kpPreeditText
{
public:
    kpPreeditText ();
    kpPreeditText (const QInputMethodEvent *event);

    bool isEmpty () const;

    const QString &preeditString () const;
    int cursorPosition () const;
    bool cursorVisible () const;
    const QColor &cursorColor () const;
    int selectionStart () const;
    int selectionLength () const;
    const QList<QInputMethodEvent::Attribute> &textFormatList () const;

    const QPoint &position () const;
    void setPosition (const QPoint &position);

private:
    QString m_preeditString;
    int m_cursorPosition;
    QColor m_cursorColor;
    int m_selectionStart;
    int m_selectionLength;
    QList<QInputMethodEvent::Attribute> m_textFormatList;
    QPoint m_position;
};

#endif  // kpPreeditText_H

==> kolourpaint-24.12.3.tar.xz: kolourpaint-24.12.3/layers/selections/text/kpPreeditText.h <==

/*
   Copyright (c) 2010 Tasuku Suzuki <stasuku@gmail.com>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpPreeditText_H
#define kpPreeditText_H

#include <QColor>
#include <QInputMethodEvent>
#include <QPoint>

class kpPreeditText
{
public:
    kpPreeditText ();
    explicit kpPreeditText (const QInputMethodEvent *event);

    bool isEmpty () const;

    const QString &preeditString () const;
    int cursorPosition () const;
    bool cursorVisible () const;
    const QColor &cursorColor () const;
    int selectionStart () const;
    int selectionLength () const;
    const QList<QInputMethodEvent::Attribute> &textFormatList () const;

    const QPoint &position () const;
    void setPosition (const QPoint &position);

private:
    QString m_preeditString;
    int m_cursorPosition;
    QColor m_cursorColor;
    int m_selectionStart;
    int m_selectionLength;
    QList<QInputMethodEvent::Attribute> m_textFormatList;
    QPoint m_position;
};

#endif  // kpPreeditText_H
